# Bouncing Pico Icon
# Tony Goodhew 8th March 2021
# SSD1306 I2C with SCL on GP9 and SDA on GP8
# Needs SSD1306 library installed
# See https://www.instructables.com/SSD1306-With-Raspberry-Pi-Pico/
# for download if needed
from machine import Pin, I2C
from ssd1306 import SSD1306_I2C
import framebuf
from time import sleep

WIDTH  = 128                                            # oled display width
HEIGHT = 64                                             # oled display height

i2c = I2C(0)                                            # Init I2C using I2C0 defaults, SCL=Pin(GP9), SDA=Pin(GP8), freq=400000
print("I2C Address      : "+hex(i2c.scan()[0]).upper()) # Display device address
print("I2C Configuration: "+str(i2c))                   # Display I2C config

oled = SSD1306_I2C(WIDTH, HEIGHT, i2c)                  # Init oled display

# Raspberry Pi logo as 32x32 bytearray
#buffer = bytearray(b"\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00|?\x00\x01\x86@\x80\x01\x01\x80\x80\x01\x11\x88\x80\x01\x05\xa0\x80\x00\x83\xc1\x00\x00C\xe3\x00\x00~\xfc\x00\x00L'\x00\x00\x9c\x11\x00\x00\xbf\xfd\x00\x00\xe1\x87\x00\x01\xc1\x83\x80\x02A\x82@\x02A\x82@\x02\xc1\xc2@\x02\xf6>\xc0\x01\xfc=\x80\x01\x18\x18\x80\x01\x88\x10\x80\x00\x8c!\x00\x00\x87\xf1\x00\x00\x7f\xf6\x00\x008\x1c\x00\x00\x0c \x00\x00\x03\xc0\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00")
# Pico logo as 32 x 32 byte array
buffer3 = bytearray(b"\x00\x00\x00\x00\x7F\x80\x01\x98\x7F\x80\x03\xFC\x60\x60\x03\x6C\x60\x60\x03\xFC\x60\x18\x03\xFC\x60\x18\x01\x98\x60\x60\x00\xF0\x60\x60\x00\x60\x7F\x80\x00\x00\x7F\x80\x00\x00\x60\x00\x00\x00\x66\x3C\x0F\x00\x66\x7F\x3F\xC0\x60\x63\x30\xC0\x66\x60\x20\x40\x66\x60\x20\x40\x66\x60\x20\x40\x66\x63\x30\xC0\x66\x7F\x3F\xC0\x06\x3C\x0F\x00\x00\x00\x00\x00\x00\x00\x00\x00\x3F\xFF\xFF\xF8\x00\x00\x00\x00\x3F\xFF\xFF\xF8\x00\x00\x00\x00\x15\x55\x55\x50\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00")
# Load the logo into the framebuffer (the image is 32x32)
fb = framebuf.FrameBuffer(buffer3, 32, 32, framebuf.MONO_HLSB)
# Clear the oled display in case it has junk on it.
oled.fill(0)
dx = 1
dy = 1
x = 13
y = 10
c = 1
while True:
    oled.blit(fb, x, y)
    x = x + dx
    y = y + dy
    if (x == 95) or (x == 1):
        dx = dx * -1
    if (y == 31) or (y == 1):
        dy = dy * -1
    oled.show()



  